@@ -1,10 +1,14 @@
 from .main import BaseSettings, SettingsConfigDict
 from .sources import (
+    CliPositionalArg,
+    CliSettingsSource,
+    CliSubCommand,
     DotEnvSettingsSource,
     EnvSettingsSource,
     InitSettingsSource,
     JsonConfigSettingsSource,
     PydanticBaseSettingsSource,
+    PyprojectTomlConfigSettingsSource,
     SecretsSettingsSource,
     TomlConfigSettingsSource,
     YamlConfigSettingsSource,
@@ -15,8 +19,12 @@ __all__ = (
     'BaseSettings',
     'DotEnvSettingsSource',
     'EnvSettingsSource',
+    'CliSettingsSource',
+    'CliSubCommand',
+    'CliPositionalArg',
     'InitSettingsSource',
     'JsonConfigSettingsSource',
+    'PyprojectTomlConfigSettingsSource',
     'PydanticBaseSettingsSource',
     'SecretsSettingsSource',
     'SettingsConfigDict',
